# mfNRcatpy

mfNRcatpy is a Python package designed for analyzing Gravitational-wave data, created and maintained by Sebastian Gomez Lopez. The package includes a variety of tools for working with binary neutron star numerical relativity waveform catalogs and the matched filtering algorithm.

# Installation

- Clone the repository from the [source](https://github.com/sebastiangomezlopez/mfNRcatpy) and run the command `pip install ./mfNRcatpy`.

- Alternatively, you can install it from Pypi by running the command `pip install mfNRcatpy`.

For those looking to learn more about the package's basic functionalities, we recommend checking out the [example notebooks](https://github.com/sebastiangomezlopez/mfNRcatpy/tree/main/examples), which provide detailed explanations.
